diff --git a/src/backend/access/gist/gist.c b/src/backend/access/gist/gist.c
index 425c354302d822296ced63852f1de8dfb9ad59f8..6b873ab84afa5a4d579d3dd0f54dc1839f7eec4c 100644
--- a/src/backend/access/gist/gist.c
+++ b/src/backend/access/gist/gist.c
@@ -6,7 +6,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/access/gist/gist.c,v 1.47 1999/11/07 23:07:48 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/access/gist/gist.c,v 1.48 1999/12/10 03:55:42 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -264,7 +264,7 @@ gistbuild(Relation heap,
 	if (pred != NULL || oldPred != NULL)
 	{
 #ifndef OMIT_PARTIAL_INDEX
-		ExecDestroyTupleTable(tupleTable, true);
+		ExecDropTupleTable(tupleTable, true);
 		pfree(econtext);
 #endif	 /* OMIT_PARTIAL_INDEX */
 	}
diff --git a/src/backend/access/hash/hash.c b/src/backend/access/hash/hash.c
index ca7c14d30df7194ec71a24f5992250aaff1d8ce0..fd3e3f94d50edbe36c328673f29282db206805c1 100644
--- a/src/backend/access/hash/hash.c
+++ b/src/backend/access/hash/hash.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/access/hash/hash.c,v 1.32 1999/09/24 00:23:48 tgl Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/access/hash/hash.c,v 1.33 1999/12/10 03:55:43 momjian Exp $
  *
  * NOTES
  *	  This file contains only the public interface routines.
@@ -221,7 +221,7 @@ hashbuild(Relation heap,
 	if (pred != NULL || oldPred != NULL)
 	{
 #ifndef OMIT_PARTIAL_INDEX
-		ExecDestroyTupleTable(tupleTable, true);
+		ExecDropTupleTable(tupleTable, true);
 		pfree(econtext);
 #endif	 /* OMIT_PARTIAL_INDEX */
 	}
diff --git a/src/backend/access/nbtree/nbtree.c b/src/backend/access/nbtree/nbtree.c
index e1260808b355e7ee3c92632863c61db1e0297a46..458b427c70d17f7a9ee811449f0b86035235d660 100644
--- a/src/backend/access/nbtree/nbtree.c
+++ b/src/backend/access/nbtree/nbtree.c
@@ -11,7 +11,7 @@
  * Copyright (c) 1994, Regents of the University of California
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/access/nbtree/nbtree.c,v 1.49 1999/12/01 00:29:53 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/access/nbtree/nbtree.c,v 1.50 1999/12/10 03:55:44 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -269,7 +269,7 @@ btbuild(Relation heap,
 	if (pred != NULL || oldPred != NULL)
 	{
 #ifndef OMIT_PARTIAL_INDEX
-		ExecDestroyTupleTable(tupleTable, true);
+		ExecDropTupleTable(tupleTable, true);
 		pfree(econtext);
 #endif	 /* OMIT_PARTIAL_INDEX */
 	}
diff --git a/src/backend/access/rtree/rtree.c b/src/backend/access/rtree/rtree.c
index d12e21c9cd1cf3bcf95a70233d4afc3d55ca6cfc..09930e1e340680637cd250cb73ce3544b5f4f82c 100644
--- a/src/backend/access/rtree/rtree.c
+++ b/src/backend/access/rtree/rtree.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/access/rtree/Attic/rtree.c,v 1.40 1999/11/15 09:59:00 ishii Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/access/rtree/Attic/rtree.c,v 1.41 1999/12/10 03:55:45 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -240,7 +240,7 @@ rtbuild(Relation heap,
 	if (pred != NULL || oldPred != NULL)
 	{
 #ifndef OMIT_PARTIAL_INDEX
-		ExecDestroyTupleTable(tupleTable, true);
+		ExecDropTupleTable(tupleTable, true);
 		pfree(econtext);
 #endif	 /* OMIT_PARTIAL_INDEX */
 	}
diff --git a/src/backend/access/transam/xact.c b/src/backend/access/transam/xact.c
index f468e2916b164cb7a9faebe1eba2e06ec0eaf0fe..a9dc4db834880f86c8c949222ff021ab6b66a2a9 100644
--- a/src/backend/access/transam/xact.c
+++ b/src/backend/access/transam/xact.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/access/transam/xact.c,v 1.55 1999/09/29 16:05:55 wieck Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/access/transam/xact.c,v 1.56 1999/12/10 03:55:46 momjian Exp $
  *
  * NOTES
  *		Transaction aborts can now occur two ways:
@@ -938,7 +938,7 @@ CommitTransaction()
 	AtCommit_Notify();
 
 	CloseSequences();
-	DestroyNoNameRels();
+	DropNoNameRels();
 	AtEOXact_portals();
 	RecordTransactionCommit();
 
@@ -1034,7 +1034,7 @@ AbortTransaction()
 		vc_abort();
 	RecordTransactionAbort();
 	RelationPurgeLocalRelation(false);
-	DestroyNoNameRels();
+	DropNoNameRels();
 	invalidate_temp_relations();
 	AtEOXact_nbtree();
 	AtAbort_Cache();
diff --git a/src/backend/commands/cluster.c b/src/backend/commands/cluster.c
index d2cdfb332ee7789cae4b9e5f2fe1468cdfa37f39..ded4c7ea61d562626de63cf96b3b3ee28ac856be 100644
--- a/src/backend/commands/cluster.c
+++ b/src/backend/commands/cluster.c
@@ -14,7 +14,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/commands/cluster.c,v 1.47 1999/11/22 17:56:00 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/commands/cluster.c,v 1.48 1999/12/10 03:55:49 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -151,7 +151,7 @@ cluster(char *oldrelname, char *oldindexname)
 
 
 	/* Destroy old heap (along with its index) and rename new. */
-	heap_destroy_with_catalog(oldrelname);
+	heap_drop_with_catalog(oldrelname);
 
 	CommitTransactionCommand();
 	StartTransactionCommand();
diff --git a/src/backend/commands/command.c b/src/backend/commands/command.c
index 84e9331abe781b16545808076bcd90ba35e71baa..c26228677e90a1ebf64ffd4064f0109e6aa829b2 100644
--- a/src/backend/commands/command.c
+++ b/src/backend/commands/command.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/commands/Attic/command.c,v 1.58 1999/11/24 00:44:30 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/commands/Attic/command.c,v 1.59 1999/12/10 03:55:49 momjian Exp $
  *
  * NOTES
  *	  The PortalExecutorHeapMemory crap needs to be eliminated
@@ -242,7 +242,7 @@ PerformPortalClose(char *name, CommandDest dest)
 	 *	Note: PortalCleanup is called as a side-effect
 	 * ----------------
 	 */
-	PortalDestroy(&portal);
+	PortalDrop(&portal);
 }
 
 /* ----------------
diff --git a/src/backend/commands/creatinh.c b/src/backend/commands/creatinh.c
index 6d7ceab1a1879ca3aae58745d6ff51d7bc3364a4..4dded845afd2db5996a306c4307c0d5df1761451 100644
--- a/src/backend/commands/creatinh.c
+++ b/src/backend/commands/creatinh.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/commands/Attic/creatinh.c,v 1.52 1999/11/22 17:56:01 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/commands/Attic/creatinh.c,v 1.53 1999/12/10 03:55:49 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -214,7 +214,7 @@ void
 RemoveRelation(char *name)
 {
 	AssertArg(name);
-	heap_destroy_with_catalog(name);
+	heap_drop_with_catalog(name);
 }
 
 /*
diff --git a/src/backend/commands/indexcmds.c b/src/backend/commands/indexcmds.c
index 62eed986657922b02ce3b8fafd7cd9e739c7472c..ab3badf9704974bffc7eb916189244e7e1ce8984 100644
--- a/src/backend/commands/indexcmds.c
+++ b/src/backend/commands/indexcmds.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/commands/indexcmds.c,v 1.14 1999/11/22 17:56:01 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/commands/indexcmds.c,v 1.15 1999/12/10 03:55:49 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -564,5 +564,5 @@ RemoveIndex(char *name)
 			 ((Form_pg_class) GETSTRUCT(tuple))->relkind);
 	}
 
-	index_destroy(tuple->t_data->t_oid);
+	index_drop(tuple->t_data->t_oid);
 }
diff --git a/src/backend/commands/remove.c b/src/backend/commands/remove.c
index 65366a8ad7c404973d90c066148f526bd8bb9e07..6cf94518e2d2be39a93eebcf3b9cb57080797929 100644
--- a/src/backend/commands/remove.c
+++ b/src/backend/commands/remove.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/commands/Attic/remove.c,v 1.40 1999/11/22 17:56:02 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/commands/Attic/remove.c,v 1.41 1999/12/10 03:55:49 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -234,7 +234,7 @@ AttributeAndRelationRemove(Oid typeOid)
 			char	   *name;
 
 			name = NameStr(((Form_pg_class) GETSTRUCT(tup))->relname);
-			heap_destroy_with_catalog(name);
+			heap_drop_with_catalog(name);
 		}
 		heap_endscan(scan);
 	}
diff --git a/src/backend/commands/view.c b/src/backend/commands/view.c
index 65c46d271a5104f438cd929bea5febfdda949e79..4729566721db3465e2bbf5b240e0f83e4becd27e 100644
--- a/src/backend/commands/view.c
+++ b/src/backend/commands/view.c
@@ -5,7 +5,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- *	$Id: view.c,v 1.39 1999/10/07 04:23:00 tgl Exp $
+ *	$Id: view.c,v 1.40 1999/12/10 03:55:50 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -305,6 +305,6 @@ RemoveView(char *viewName)
 	/*
 	 * now remove the relation.
 	 */
-	heap_destroy_with_catalog(viewName);
+	heap_drop_with_catalog(viewName);
 	pfree(rname);
 }
diff --git a/src/backend/executor/_deadcode/nodeTee.c b/src/backend/executor/_deadcode/nodeTee.c
index 7cab4084a868cf352875cb9c0984d63a8e937a97..1931ebcf535867cecdf2dd8067869dd5bcb3e569 100644
--- a/src/backend/executor/_deadcode/nodeTee.c
+++ b/src/backend/executor/_deadcode/nodeTee.c
@@ -14,7 +14,7 @@
  *		ExecInitTee
  *		ExecEndTee
  *
- *	$Id: nodeTee.c,v 1.5 1999/07/16 04:58:54 momjian Exp $
+ *	$Id: nodeTee.c,v 1.6 1999/12/10 03:55:52 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -470,7 +470,7 @@ ExecEndTee(Tee * node, Plan *parent)
 		bufferRel = teeState->tee_bufferRel;
 		if (bufferRel)
 		{
-			heap_destroy(bufferRel);
+			heap_drop(bufferRel);
 			teeState->tee_bufferRel = NULL;
 			if (teeState->tee_mcxt)
 			{
diff --git a/src/backend/executor/execMain.c b/src/backend/executor/execMain.c
index 4d5b25a7d9f864d752d8419729ef96f144f474c6..bea42714aa44c7dca556aa81d47894a0cecc1c3d 100644
--- a/src/backend/executor/execMain.c
+++ b/src/backend/executor/execMain.c
@@ -26,7 +26,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/executor/execMain.c,v 1.101 1999/11/24 00:44:31 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/executor/execMain.c,v 1.102 1999/12/10 03:55:51 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -778,7 +778,7 @@ EndPlan(Plan *plan, EState *estate)
 	{
 		TupleTable	tupleTable = (TupleTable) estate->es_tupleTable;
 
-		ExecDestroyTupleTable(tupleTable, true);
+		ExecDropTupleTable(tupleTable, true);
 		estate->es_tupleTable = NULL;
 	}
 
diff --git a/src/backend/executor/nodeHash.c b/src/backend/executor/nodeHash.c
index c6295acf7237a23947202302a1298ce135065f2c..12dbcec122fb67f49742d25dc53f2c6ee7508afa 100644
--- a/src/backend/executor/nodeHash.c
+++ b/src/backend/executor/nodeHash.c
@@ -6,7 +6,7 @@
  * Copyright (c) 1994, Regents of the University of California
  *
  *
- *	$Id: nodeHash.c,v 1.39 1999/10/13 15:02:25 tgl Exp $
+ *	$Id: nodeHash.c,v 1.40 1999/12/10 03:55:51 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -439,7 +439,7 @@ ExecHashTableDestroy(HashJoinTable hashtable)
 
 	/* Destroy the portal to release all working memory */
 	/* cast here is a kluge for circular includes... */
-	PortalDestroy((Portal *) &hashtable->myPortal);
+	PortalDrop((Portal *) &hashtable->myPortal);
 
 	/* And drop the control block */
 	pfree(hashtable);
diff --git a/src/backend/executor/nodeMaterial.c b/src/backend/executor/nodeMaterial.c
index 24232617cf6e2ed5e12cbc7766e0ab16d9056575..c80152d61d823b26b239a490265ba7afbcbd9207 100644
--- a/src/backend/executor/nodeMaterial.c
+++ b/src/backend/executor/nodeMaterial.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/executor/nodeMaterial.c,v 1.26 1999/09/24 00:24:23 tgl Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/executor/nodeMaterial.c,v 1.27 1999/12/10 03:55:51 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -311,7 +311,7 @@ ExecEndMaterial(Material *node)
 	matstate = node->matstate;
 	tempRelation = matstate->mat_TempRelation;
 
-	heap_destroy(tempRelation);
+	heap_drop(tempRelation);
 
 	/* ----------------
 	 *	close the temp relation and shut down the scan.
diff --git a/src/backend/executor/spi.c b/src/backend/executor/spi.c
index e99475942b996644c5c73283abdbfad85678802c..c0231ce317aeeba06d1d41538d6b0a96f2c77ee8 100644
--- a/src/backend/executor/spi.c
+++ b/src/backend/executor/spi.c
@@ -3,7 +3,7 @@
  * spi.c
  *				Server Programming Interface
  *
- * $Id: spi.c,v 1.42 1999/11/22 17:56:05 momjian Exp $
+ * $Id: spi.c,v 1.43 1999/12/10 03:55:51 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -127,7 +127,7 @@ SPI_finish()
 
 	/* Restore memory context as it was before procedure call */
 	MemoryContextSwitchTo(_SPI_current->savedcxt);
-	PortalDestroy(&(_SPI_current->portal));
+	PortalDrop(&(_SPI_current->portal));
 
 	SetScanCommandId(_SPI_current->savedId);
 
diff --git a/src/backend/parser/gram.y b/src/backend/parser/gram.y
index b7724b74a8efe41867dcf158ccd390bca4e56c8c..03a14ad232a7598c9683fe63cab60bc5227a71f1 100644
--- a/src/backend/parser/gram.y
+++ b/src/backend/parser/gram.y
@@ -10,7 +10,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/parser/gram.y,v 2.118 1999/12/10 03:01:05 tgl Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/parser/gram.y,v 2.119 1999/12/10 03:55:54 momjian Exp $
  *
  * HISTORY
  *	  AUTHOR			DATE			MAJOR EVENT
@@ -116,7 +116,7 @@ static Node *doNegate(Node *n);
 
 %type <node>	stmt,
 		AddAttrStmt, ClosePortalStmt,
-		CopyStmt, CreateStmt, CreateAsStmt, CreateSeqStmt, DefineStmt, DestroyStmt,
+		CopyStmt, CreateStmt, CreateAsStmt, CreateSeqStmt, DefineStmt, DropStmt,
 		TruncateStmt, CommentStmt,
 		ExtendStmt, FetchStmt,	GrantStmt, CreateTrigStmt, DropTrigStmt,
 		CreatePLangStmt, DropPLangStmt,
@@ -124,7 +124,7 @@ static Node *doNegate(Node *n);
 		ProcedureStmt, RemoveAggrStmt, RemoveOperStmt,
 		RemoveFuncStmt, RemoveStmt,
 		RenameStmt, RevokeStmt, RuleStmt, TransactionStmt, ViewStmt, LoadStmt,
-		CreatedbStmt, DestroydbStmt, VacuumStmt, CursorStmt, SubSelect,
+		CreatedbStmt, DropdbStmt, VacuumStmt, CursorStmt, SubSelect,
 		UpdateStmt, InsertStmt, select_clause, SelectStmt, NotifyStmt, DeleteStmt, 
 		ClusterStmt, ExplainStmt, VariableSetStmt, VariableShowStmt, VariableResetStmt,
 		CreateUserStmt, AlterUserStmt, DropUserStmt, RuleActionStmt,
@@ -402,7 +402,7 @@ stmt :	  AddAttrStmt
 		| CreateUserStmt
 		| ClusterStmt
 		| DefineStmt
-		| DestroyStmt		
+		| DropStmt		
 		| TruncateStmt
 		| CommentStmt
 		| DropPLangStmt
@@ -429,7 +429,7 @@ stmt :	  AddAttrStmt
 		| ViewStmt
 		| LoadStmt
 		| CreatedbStmt
-		| DestroydbStmt
+		| DropdbStmt
 		| VacuumStmt
 		| VariableSetStmt
 		| VariableShowStmt
@@ -1621,20 +1621,20 @@ def_arg:  ColId							{  $$ = (Node *)makeString($1); }
 /*****************************************************************************
  *
  *		QUERY:
- *				destroy <relname1> [, <relname2> .. <relnameN> ]
+ *				drop <relname1> [, <relname2> .. <relnameN> ]
  *
  *****************************************************************************/
 
-DestroyStmt:  DROP TABLE relation_name_list
+DropStmt:  DROP TABLE relation_name_list
 				{
-					DestroyStmt *n = makeNode(DestroyStmt);
+					DropStmt *n = makeNode(DropStmt);
 					n->relNames = $3;
 					n->sequence = FALSE;
 					$$ = (Node *)n;
 				}
 		| DROP SEQUENCE relation_name_list
 				{
-					DestroyStmt *n = makeNode(DestroyStmt);
+					DropStmt *n = makeNode(DropStmt);
 					n->relNames = $3;
 					n->sequence = TRUE;
 					$$ = (Node *)n;
@@ -2495,13 +2495,13 @@ encoding:  Sconst								{ $$ = $1; }
 /*****************************************************************************
  *
  *		QUERY:
- *				destroydb dbname
+ *				dropdb dbname
  *
  *****************************************************************************/
 
-DestroydbStmt:	DROP DATABASE database_name
+DropdbStmt:	DROP DATABASE database_name
 				{
-					DestroydbStmt *n = makeNode(DestroydbStmt);
+					DropdbStmt *n = makeNode(DropdbStmt);
 					n->dbname = $3;
 					$$ = (Node *)n;
 				}
diff --git a/src/backend/storage/large_object/inv_api.c b/src/backend/storage/large_object/inv_api.c
index d28443a46ea8ba187117112a075621b48516406f..9026e8124fc5c15b0eb35bea5b6d5084aa0afff6 100644
--- a/src/backend/storage/large_object/inv_api.c
+++ b/src/backend/storage/large_object/inv_api.c
@@ -8,7 +8,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/storage/large_object/inv_api.c,v 1.61 1999/11/07 23:08:16 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/storage/large_object/inv_api.c,v 1.62 1999/12/10 03:55:57 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -274,7 +274,7 @@ inv_close(LargeObjectDesc *obj_desc)
  * returns -1 if failed
  */
 int
-inv_destroy(Oid lobjId)
+inv_drop(Oid lobjId)
 {
 	Relation	r;
 
@@ -282,7 +282,7 @@ inv_destroy(Oid lobjId)
 	if (!RelationIsValid(r) || r->rd_rel->relkind != RELKIND_LOBJECT)
 		return -1;
 
-	heap_destroy_with_catalog(RelationGetRelationName(r));
+	heap_drop_with_catalog(RelationGetRelationName(r));
 	return 1;
 }
 
diff --git a/src/backend/tcop/utility.c b/src/backend/tcop/utility.c
index 3b2660a270c5bfc962781ae2739832902a293688..6c22afa5458fca4ca0f36666b193ec4023020680 100644
--- a/src/backend/tcop/utility.c
+++ b/src/backend/tcop/utility.c
@@ -9,7 +9,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/tcop/utility.c,v 1.72 1999/11/21 04:16:16 tgl Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/tcop/utility.c,v 1.73 1999/12/10 03:55:59 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -162,9 +162,9 @@ ProcessUtility(Node *parsetree,
 			DefineRelation((CreateStmt *) parsetree, RELKIND_RELATION);
 			break;
 
-		case T_DestroyStmt:
+		case T_DropStmt:
 			{
-				DestroyStmt *stmt = (DestroyStmt *) parsetree;
+				DropStmt *stmt = (DropStmt *) parsetree;
 				List	   *args = stmt->relNames;
 				List	   *arg;
 
@@ -592,19 +592,19 @@ ProcessUtility(Node *parsetree,
 			{
 				CreatedbStmt *stmt = (CreatedbStmt *) parsetree;
 
-				PS_SET_STATUS(commandTag = "CREATEDB");
+				PS_SET_STATUS(commandTag = "CREATE DATABASE");
 				CHECK_IF_ABORTED();
 				createdb(stmt->dbname, stmt->dbpath, stmt->encoding, dest);
 			}
 			break;
 
-		case T_DestroydbStmt:
+		case T_DropdbStmt:
 			{
-				DestroydbStmt *stmt = (DestroydbStmt *) parsetree;
+				DropdbStmt *stmt = (DropdbStmt *) parsetree;
 
-				PS_SET_STATUS(commandTag = "DESTROYDB");
+				PS_SET_STATUS(commandTag = "DROP DATABASE");
 				CHECK_IF_ABORTED();
-				destroydb(stmt->dbname, dest);
+				dropdb(stmt->dbname, dest);
 			}
 			break;
 
diff --git a/src/backend/utils/cache/temprel.c b/src/backend/utils/cache/temprel.c
index 9bf51cfec3341ab2d336df9c40733cc27d91f388..23ac1aadbcf477952a3bf3c3eba50984ab0dd198 100644
--- a/src/backend/utils/cache/temprel.c
+++ b/src/backend/utils/cache/temprel.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/utils/cache/Attic/temprel.c,v 1.17 1999/11/16 16:55:28 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/utils/cache/Attic/temprel.c,v 1.18 1999/12/10 03:56:00 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -98,10 +98,10 @@ remove_all_temp_relations(void)
 
 			/* safe from deallocation */
 			strcpy(relname, temp_rel->user_relname);
-			heap_destroy_with_catalog(relname);
+			heap_drop_with_catalog(relname);
 		}
 		else
-			index_destroy(temp_rel->relid);
+			index_drop(temp_rel->relid);
 
 		l = next;
 	}
diff --git a/src/backend/utils/mmgr/portalmem.c b/src/backend/utils/mmgr/portalmem.c
index 4120c24dd677d1b244e77580e062e59870f0f8d2..aaec2dfd65aee60f803b518b24c7effc399dd49b 100644
--- a/src/backend/utils/mmgr/portalmem.c
+++ b/src/backend/utils/mmgr/portalmem.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/utils/mmgr/portalmem.c,v 1.30 1999/09/23 17:02:58 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/utils/mmgr/portalmem.c,v 1.31 1999/12/10 03:56:03 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -438,7 +438,7 @@ CollectNamedPortals(Portal *portalP, int destroy)
 		int			i;
 
 		for (i = 0; i < listIndex; i++)
-			PortalDestroy(&portalList[i]);
+			PortalDrop(&portalList[i]);
 		listIndex = 0;
 	}
 	else
@@ -546,7 +546,7 @@ EnablePortalManager(bool on)
 	{							/* cleanup */
 		if (PortalIsValid(BlankPortal))
 		{
-			PortalDestroy(&BlankPortal);
+			PortalDrop(&BlankPortal);
 			MemoryContextFree((MemoryContext) PortalMemory,
 							  (Pointer) BlankPortal);
 			BlankPortal = NULL;
@@ -555,7 +555,7 @@ EnablePortalManager(bool on)
 		/*
 		 * Each portal must free its non-memory resources specially.
 		 */
-		HashTableWalk(PortalHashTable, PortalDestroy, 0);
+		HashTableWalk(PortalHashTable, PortalDrop, 0);
 		hash_destroy(PortalHashTable);
 		PortalHashTable = NULL;
 
@@ -774,7 +774,7 @@ CreatePortal(char *name)		/* XXX PortalName */
 }
 
 /*
- * PortalDestroy
+ * PortalDrop
  *		Destroys portal.
  *
  * Exceptions:
@@ -782,7 +782,7 @@ CreatePortal(char *name)		/* XXX PortalName */
  *		BadArg if portal is invalid.
  */
 void
-PortalDestroy(Portal *portalP)
+PortalDrop(Portal *portalP)
 {
 	Portal		portal = *portalP;
 
diff --git a/src/include/catalog/heap.h b/src/include/catalog/heap.h
index 9d311038cbdab0b794f5d0f4bf59737105ae4cb5..4370247a6b30895bb883ee8d2eaaef6cb8012700 100644
--- a/src/include/catalog/heap.h
+++ b/src/include/catalog/heap.h
@@ -6,7 +6,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: heap.h,v 1.25 1999/11/04 08:01:04 inoue Exp $
+ * $Id: heap.h,v 1.26 1999/12/10 03:56:05 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -29,15 +29,15 @@ extern bool heap_storage_create(Relation rel);
 extern Oid heap_create_with_catalog(char *relname, TupleDesc tupdesc, 
 				    char relkind, bool istemp);
 
-extern void heap_destroy_with_catalog(char *relname);
+extern void heap_drop_with_catalog(char *relname);
 extern void heap_truncate(char *relname);
-extern void heap_destroy(Relation rel);
+extern void heap_drop(Relation rel);
 
 extern void AddRelationRawConstraints(Relation rel,
 				      List *rawColDefaults,
 				      List *rawConstraints);
 
 extern void InitNoNameRelList(void);
-extern void DestroyNoNameRels(void);
+extern void DropNoNameRels(void);
 
 #endif	 /* HEAP_H */
diff --git a/src/include/catalog/index.h b/src/include/catalog/index.h
index 004d2461886f79d407c8cb262095ff9306294e06..30d1b9d7455c5cc15b7b0225187fa7e890ac4c42 100644
--- a/src/include/catalog/index.h
+++ b/src/include/catalog/index.h
@@ -6,7 +6,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: index.h,v 1.19 1999/07/16 17:07:29 momjian Exp $
+ * $Id: index.h,v 1.20 1999/12/10 03:56:05 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@ extern void index_create(char *heapRelationName,
 			 bool unique,
 			 bool primary);
 
-extern void index_destroy(Oid indexId);
+extern void index_drop(Oid indexId);
 
 extern void FormIndexDatum(int numberOfAttributes,
 			   AttrNumber *attributeNumber, HeapTuple heapTuple,
diff --git a/src/include/commands/dbcommands.h b/src/include/commands/dbcommands.h
index bad0e1513d448b1f9799b58615a91968204fa60f..165b20505f4a1ed6368f207cda0e8d9583d44844 100644
--- a/src/include/commands/dbcommands.h
+++ b/src/include/commands/dbcommands.h
@@ -6,7 +6,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: dbcommands.h,v 1.10 1999/07/15 15:21:01 momjian Exp $
+ * $Id: dbcommands.h,v 1.11 1999/12/10 03:56:06 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -23,6 +23,6 @@
 #define SIGKILLDAEMON1	SIGTERM
 
 extern void createdb(char *dbname, char *dbpath, int encoding, CommandDest);
-extern void destroydb(char *dbname, CommandDest);
+extern void dropdb(char *dbname, CommandDest);
 
 #endif	 /* DBCOMMANDS_H */
diff --git a/src/include/executor/executor.h b/src/include/executor/executor.h
index cf9ec0d291d8928a46f2821eeb36645a5ad89a99..af599330a096617e4ec5765d22387a365a093289 100644
--- a/src/include/executor/executor.h
+++ b/src/include/executor/executor.h
@@ -6,7 +6,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: executor.h,v 1.39 1999/10/30 23:13:30 tgl Exp $
+ * $Id: executor.h,v 1.40 1999/12/10 03:56:08 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -107,7 +107,7 @@ extern TupleTableSlot *ExecScan(Scan *node, TupleTableSlot *(*accessMtd) ());
  * prototypes from functions in execTuples.c
  */
 extern TupleTable ExecCreateTupleTable(int initialSize);
-extern void ExecDestroyTupleTable(TupleTable table, bool shouldFree);
+extern void ExecDropTupleTable(TupleTable table, bool shouldFree);
 extern TupleTableSlot *ExecAllocTableSlot(TupleTable table);
 extern TupleTableSlot *ExecStoreTuple(HeapTuple tuple,
 			   TupleTableSlot *slot,
diff --git a/src/include/nodes/nodes.h b/src/include/nodes/nodes.h
index ffb7ca848fbd4f07684424be16f02922936b4212..d362e0a28e995c4e4f02a716c29c10b3f8de21c8 100644
--- a/src/include/nodes/nodes.h
+++ b/src/include/nodes/nodes.h
@@ -6,7 +6,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: nodes.h,v 1.57 1999/12/06 18:02:46 wieck Exp $
+ * $Id: nodes.h,v 1.58 1999/12/10 03:56:09 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -153,7 +153,7 @@ typedef enum NodeTag
 	T_CreateStmt,
 	T_VersionStmt,
 	T_DefineStmt,
-	T_DestroyStmt,
+	T_DropStmt,
 	T_TruncateStmt,
 	T_CommentStmt,
 	T_ExtendStmt,
@@ -173,7 +173,7 @@ typedef enum NodeTag
 	T_ViewStmt,
 	T_LoadStmt,
 	T_CreatedbStmt,
-	T_DestroydbStmt,
+	T_DropdbStmt,
 	T_VacuumStmt,
 	T_ExplainStmt,
 	T_CreateSeqStmt,
diff --git a/src/include/nodes/parsenodes.h b/src/include/nodes/parsenodes.h
index 542760a2357697fe8f4357c32413c2a7b6fcdc28..bcff7aa30066fe23b813c8570eb1ee6dcc0d55e8 100644
--- a/src/include/nodes/parsenodes.h
+++ b/src/include/nodes/parsenodes.h
@@ -6,7 +6,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: parsenodes.h,v 1.88 1999/12/06 18:02:47 wieck Exp $
+ * $Id: parsenodes.h,v 1.89 1999/12/10 03:56:09 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -325,12 +325,12 @@ typedef struct DefineStmt
  *		Drop Table Statement
  * ----------------------
  */
-typedef struct DestroyStmt
+typedef struct DropStmt
 {
 	NodeTag		type;
 	List	   *relNames;		/* relations to be dropped */
 	bool		sequence;
-} DestroyStmt;
+} DropStmt;
 
 /* ----------------------
  *              Truncate Table Statement
@@ -577,14 +577,14 @@ typedef struct CreatedbStmt
 } CreatedbStmt;
 
 /* ----------------------
- *		Destroydb Statement
+ *		Dropdb Statement
  * ----------------------
  */
-typedef struct DestroydbStmt
+typedef struct DropdbStmt
 {
 	NodeTag		type;
 	char	   *dbname;			/* database to drop */
-} DestroydbStmt;
+} DropdbStmt;
 
 /* ----------------------
  *		Cluster Statement (support pbrown's cluster index implementation)
diff --git a/src/include/storage/large_object.h b/src/include/storage/large_object.h
index 52c89c4f3478a5a5ca253427bef09819d8d1ac14..c798379815ea5cae9f328c62b9c3e198e0a00cad 100644
--- a/src/include/storage/large_object.h
+++ b/src/include/storage/large_object.h
@@ -7,7 +7,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: large_object.h,v 1.11 1999/07/15 23:04:11 momjian Exp $
+ * $Id: large_object.h,v 1.12 1999/12/10 03:56:10 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ typedef struct LargeObjectDesc
 extern LargeObjectDesc *inv_create(int flags);
 extern LargeObjectDesc *inv_open(Oid lobjId, int flags);
 extern void inv_close(LargeObjectDesc *obj_desc);
-extern int	inv_destroy(Oid lobjId);
+extern int	inv_drop(Oid lobjId);
 extern int	inv_seek(LargeObjectDesc *obj_desc, int offset, int whence);
 extern int	inv_tell(LargeObjectDesc *obj_desc);
 extern int	inv_read(LargeObjectDesc *obj_desc, char *buf, int nbytes);
diff --git a/src/include/utils/portal.h b/src/include/utils/portal.h
index 62d08804607af53214633c5c3e4cb7639ad2488e..b808533f0b225316d52caa70695884ca45b4f4a3 100644
--- a/src/include/utils/portal.h
+++ b/src/include/utils/portal.h
@@ -6,7 +6,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: portal.h,v 1.19 1999/09/23 17:03:33 momjian Exp $
+ * $Id: portal.h,v 1.20 1999/12/10 03:56:12 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -73,7 +73,7 @@ extern void PortalSetQuery(Portal portal, QueryDesc *queryDesc,
 extern QueryDesc *PortalGetQueryDesc(Portal portal);
 extern EState *PortalGetState(Portal portal);
 extern Portal CreatePortal(char *name);
-extern void PortalDestroy(Portal *portalP);
+extern void PortalDrop(Portal *portalP);
 extern void StartPortalAllocMode(AllocMode mode, Size limit);
 extern void EndPortalAllocMode(void);
 extern void PortalResetHeapMemory(Portal portal);
diff --git a/src/interfaces/ecpg/preproc/preproc.y b/src/interfaces/ecpg/preproc/preproc.y
index d84d6528edad3bea70b225319478080c5d58382b..a2ac1149de2a3a2c4a66cc1905ec9bbdabd545b3 100644
--- a/src/interfaces/ecpg/preproc/preproc.y
+++ b/src/interfaces/ecpg/preproc/preproc.y
@@ -828,7 +828,7 @@ adjust_array(enum ECPGttype type_enum, int *dimension, int *length, int type_dim
 %type  <str>    NotifyStmt columnElem copy_dirn UnlistenStmt
 %type  <str>    copy_delimiter ListenStmt CopyStmt copy_file_name opt_binary
 %type  <str>    opt_with_copy FetchStmt opt_direction fetch_how_many opt_portal_name
-%type  <str>    ClosePortalStmt DestroyStmt VacuumStmt opt_verbose
+%type  <str>    ClosePortalStmt DropStmt VacuumStmt opt_verbose
 %type  <str>    opt_analyze opt_va_list va_list ExplainStmt index_params
 %type  <str>    index_list func_index index_elem opt_type opt_class access_method_clause
 %type  <str>    index_opt_unique IndexStmt set_opt func_return def_rest
@@ -850,7 +850,7 @@ adjust_array(enum ECPGttype type_enum, int *dimension, int *length, int type_dim
 %type  <str>    TriggerActionTime CreateTrigStmt DropPLangStmt PLangTrusted
 %type  <str>    CreatePLangStmt IntegerOnly TriggerFuncArgs TriggerFuncArg
 %type  <str>    ViewStmt LoadStmt CreatedbStmt opt_database1 opt_database2 location
-%type  <str>    DestroydbStmt ClusterStmt grantee RevokeStmt encoding
+%type  <str>    DropdbStmt ClusterStmt grantee RevokeStmt encoding
 %type  <str>	GrantStmt privileges operation_commalist operation
 %type  <str>	opt_cursor opt_lmode ConstraintsSetStmt comment_tg
 %type  <str>	case_expr when_clause_list case_default case_arg when_clause
@@ -918,7 +918,7 @@ stmt:  AddAttrStmt			{ output_statement($1, 0); }
 		| CreateUserStmt	{ output_statement($1, 0); }
   		| ClusterStmt		{ output_statement($1, 0); }
 		| DefineStmt 		{ output_statement($1, 0); }
-		| DestroyStmt		{ output_statement($1, 0); }
+		| DropStmt		{ output_statement($1, 0); }
 		| TruncateStmt		{ output_statement($1, 0); }
 		| DropPLangStmt		{ output_statement($1, 0); }
 		| DropTrigStmt		{ output_statement($1, 0); }
@@ -953,7 +953,7 @@ stmt:  AddAttrStmt			{ output_statement($1, 0); }
 		| ViewStmt		{ output_statement($1, 0); }
 		| LoadStmt		{ output_statement($1, 0); }
 		| CreatedbStmt		{ output_statement($1, 0); }
-		| DestroydbStmt		{ output_statement($1, 0); }
+		| DropdbStmt		{ output_statement($1, 0); }
 		| VacuumStmt		{ output_statement($1, 0); }
 		| VariableSetStmt	{ output_statement($1, 0); }
 		| VariableShowStmt	{ output_statement($1, 0); }
@@ -1904,11 +1904,11 @@ def_arg:  ColId			{  $$ = $1; }
 /*****************************************************************************
  *
  *		QUERY:
- *				destroy <relname1> [, <relname2> .. <relnameN> ]
+ *				drop <relname1> [, <relname2> .. <relnameN> ]
  *
  *****************************************************************************/
 
-DestroyStmt:  DROP TABLE relation_name_list
+DropStmt:  DROP TABLE relation_name_list
 				{
 					$$ = cat2_str(make1_str("drop table"), $3);
 				}
@@ -2552,11 +2552,11 @@ encoding:  Sconst		{ $$ = $1; }
 /*****************************************************************************
  *
  *		QUERY:
- *				destroydb dbname
+ *				dropdb dbname
  *
  *****************************************************************************/
 
-DestroydbStmt:	DROP DATABASE database_name
+DropdbStmt:	DROP DATABASE database_name
 				{
 					$$ = cat2_str(make1_str("drop database"), $3);
 				}
diff --git a/src/backend/catalog/heap.c b/src/backend/catalog/heap.c
index e726c8242d004a4de1bfa8c6f0d9dea48238b715..08107385b413b859865d18de3cfa913088899811 100644
--- a/src/backend/catalog/heap.c
+++ b/src/backend/catalog/heap.c
@@ -7,13 +7,13 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/catalog/heap.c,v 1.111 1999/11/28 02:03:04 tgl Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/catalog/heap.c,v 1.112 1999/12/10 03:55:47 momjian Exp $
  *
  *
  * INTERFACE ROUTINES
  *		heap_create()			- Create an uncataloged heap relation
  *		heap_create_with_catalog() - Create a cataloged relation
  *		heap_destroy_with_catalog() - Removes named relation from catalogs
  *
  * NOTES
  *	  this code taken from access/heap/create.c, which contains
@@ -889,7 +889,7 @@ heap_create_with_catalog(char *relname,
 
 
 /* ----------------------------------------------------------------
  *		heap_destroy_with_catalog	- removes all record of named relation from catalogs
  *
  *		1)	open relation, check for existence, etc.
  *		2)	remove inheritance information
@@ -1046,7 +1046,7 @@ RelationRemoveIndexes(Relation relation)
 						  &entry);
 
 	while (HeapTupleIsValid(tuple = heap_getnext(scan, 0)))
-		index_destroy(((Form_pg_index) GETSTRUCT(tuple))->indexrelid);
+		index_drop(((Form_pg_index) GETSTRUCT(tuple))->indexrelid);
 
 	heap_endscan(scan);
 	heap_close(indexRelation, RowExclusiveLock);
@@ -1441,12 +1441,12 @@ DeleteTypeTuple(Relation rel)
 }
 
 /* --------------------------------
- *		heap_destroy_with_catalog
+ *		heap_drop_with_catalog
  *
  * --------------------------------
  */
 void
-heap_destroy_with_catalog(char *relname)
+heap_drop_with_catalog(char *relname)
 {
 	Relation	rel;
 	Oid			rid;
@@ -1575,13 +1575,13 @@ heap_destroy_with_catalog(char *relname)
 }
 
 /*
- * heap_destroy
+ * heap_drop
  *	  destroy and close temporary relations
  *
  */
 
 void
-heap_destroy(Relation rel)
+heap_drop(Relation rel)
 {
 	ReleaseRelationBuffers(rel);
 	if (!(rel->rd_isnoname) || !(rel->rd_unlinked))
@@ -1634,7 +1634,7 @@ InitNoNameRelList(void)
 
    MODIFIES the global variable tempRels
 	  we don't really remove it, just mark it as NULL
-	  and DestroyNoNameRels will look for NULLs
+	  and DropNoNameRels will look for NULLs
 */
 static void
 RemoveFromNoNameRelList(Relation r)
@@ -1679,7 +1679,7 @@ AddToNoNameRelList(Relation r)
    go through the tempRels list and destroy each of the relations
 */
 void
-DestroyNoNameRels(void)
+DropNoNameRels(void)
 {
 	int			i;
 	Relation	rel;
@@ -1692,7 +1692,7 @@ DestroyNoNameRels(void)
 		rel = tempRels->rels[i];
 		/* rel may be NULL if it has been removed from the list already */
 		if (rel)
-			heap_destroy(rel);
+			heap_drop(rel);
 	}
 	free(tempRels->rels);
 	free(tempRels);
@@ -7,13 +7,13 @@
  *		heap_create()			- Create an uncataloged heap relation
  *		heap_create_with_catalog() - Create a cataloged relation
- *		heap_destroy_with_catalog() - Removes named relation from catalogs
+ *		heap_drop_with_catalog() - Removes named relation from catalogs
  *
  * NOTES
@@ -889,7 +889,7 @@ heap_create_with_catalog(char *relname,
 
 /* ----------------------------------------------------------------
- *		heap_destroy_with_catalog	- removes all record of named relation from catalogs
+ *		heap_drop_with_catalog	- removes all record of named relation from catalogs
  *
  *		1)	open relation, check for existence, etc.
diff --git a/src/backend/catalog/index.c b/src/backend/catalog/index.c
index 75795ca0154e46ff6485ada3d9073fa1685a7d45..ef49a46bd72b7bdf555d7dfe9eb6ef083f25e0c2 100644
--- a/src/backend/catalog/index.c
+++ b/src/backend/catalog/index.c
@@ -7,12 +7,12 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/catalog/index.c,v 1.98 1999/11/24 00:44:29 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/catalog/index.c,v 1.99 1999/12/10 03:55:48 momjian Exp $
  *
  *
  * INTERFACE ROUTINES
  *		index_create()			- Create a cataloged index relation
  *		index_destroy()			- Removes index relation from catalogs
  *
  *
  *-------------------------------------------------------------------------
@@ -1103,12 +1103,12 @@ index_create(char *heapRelationName,
 
 /* ----------------------------------------------------------------
  *
- *		index_destroy
+ *		index_drop
  *
  * ----------------------------------------------------------------
  */
 void
-index_destroy(Oid indexId)
+index_drop(Oid indexId)
 {
 	Relation	userHeapRelation;
 	Relation	userIndexRelation;
@@ -1213,7 +1213,7 @@ index_destroy(Oid indexId)
 	ReleaseRelationBuffers(userIndexRelation);
 
 	if (smgrunlink(DEFAULT_SMGR, userIndexRelation) != SM_SUCCESS)
-		elog(ERROR, "index_destroy: unlink: %m");
+		elog(ERROR, "index_drop: unlink: %m");
 
 	/*
 	 * Close rels, but keep locks
@@ -1646,7 +1646,7 @@ DefaultBuild(Relation heapRelation,
 	if (predicate != NULL || oldPred != NULL)
 	{
 		/* parameter was 'false', almost certainly wrong --- tgl 9/21/99 */
-		ExecDestroyTupleTable(tupleTable, true);
+		ExecDropTupleTable(tupleTable, true);
 	}
 #endif	 /* OMIT_PARTIAL_INDEX */
 
@@ -7,12 +7,12 @@
  * INTERFACE ROUTINES
  *		index_create()			- Create a cataloged index relation
- *		index_destroy()			- Removes index relation from catalogs
+ *		index_drop()			- Removes index relation from catalogs
  *
  *
diff --git a/src/backend/commands/dbcommands.c b/src/backend/commands/dbcommands.c
index 26f7bcf71b845f02cb84caf1e6e9bac6b50ff77b..d061b15b78dbf762d9deafcf874793de76db1604 100644
--- a/src/backend/commands/dbcommands.c
+++ b/src/backend/commands/dbcommands.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/commands/dbcommands.c,v 1.45 1999/11/24 16:52:32 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/commands/dbcommands.c,v 1.46 1999/12/10 03:55:49 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -85,7 +85,7 @@ createdb(char *dbname, char *dbpath, int encoding, CommandDest dest)
 }
 
 void
-destroydb(char *dbname, CommandDest dest)
+dropdb(char *dbname, CommandDest dest)
 {
 	int4		user_id;
 	Oid			db_id;
@@ -101,7 +101,7 @@ destroydb(char *dbname, CommandDest dest)
 	 * If this call returns, the database exists and we're allowed to
 	 * remove it.
 	 */
-	check_permissions("destroydb", dbpath, dbname, &db_id, &user_id);
+	check_permissions("dropdb", dbpath, dbname, &db_id, &user_id);
 
 	/* do as much checking as we can... */
 	if (!OidIsValid(db_id))
@@ -308,13 +308,13 @@ check_permissions(char *command,
 		elog(ERROR, "createdb: database '%s' already exists", dbname);
 
 	}
-	else if (!dbfound && !strcmp(command, "destroydb"))
+	else if (!dbfound && !strcmp(command, "dropdb"))
 	{
 
-		elog(ERROR, "destroydb: database '%s' does not exist", dbname);
+		elog(ERROR, "dropdb: database '%s' does not exist", dbname);
 
 	}
-	else if (dbfound && !strcmp(command, "destroydb")
+	else if (dbfound && !strcmp(command, "dropdb")
 			 && dbowner != *userIdP && use_super == false)
 	{
 
@@ -322,7 +322,7 @@ check_permissions(char *command,
 
 	}
 
-	if (dbfound && !strcmp(command, "destroydb"))
+	if (dbfound && !strcmp(command, "dropdb"))
 		strcpy(dbpath, path);
 }	/* check_permissions() */
 
@@ -331,7 +331,7 @@ check_permissions(char *command,
  *
  *	This is currently dead code, since we don't *have* vacuum daemons.
  *	If you want to re-enable it, think about the interlock against deleting
  *	a database out from under running backends, in destroydb() above.
  */
 static void
 stop_vacuum(char *dbpath, char *dbname)
@@ -331,7 +331,7 @@ check_permissions(char *command,
  *	This is currently dead code, since we don't *have* vacuum daemons.
  *	If you want to re-enable it, think about the interlock against deleting
- *	a database out from under running backends, in destroydb() above.
+ *	a database out from under running backends, in dropdb() above.
  */
 static void
diff --git a/src/backend/commands/vacuum.c b/src/backend/commands/vacuum.c
index 7e5d19ec67db5305cde302816f4d9233447a229b..7e0c47ef4af4ed9dc3e939cc6ec41311465fa670 100644
--- a/src/backend/commands/vacuum.c
+++ b/src/backend/commands/vacuum.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/commands/vacuum.c,v 1.129 1999/12/01 00:29:54 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/commands/vacuum.c,v 1.130 1999/12/10 03:55:49 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -218,7 +218,7 @@ vc_shutdown()
 	/*
 	 * Release our portal for cross-transaction memory.
 	 */
-	PortalDestroy(&vc_portal);
+	PortalDrop(&vc_portal);
 
 	/* okay, we're done */
 	VacuumRunning = false;
@@ -230,13 +230,13 @@ vc_shutdown()
 void
 vc_abort()
 {
 	/* Clear flag first, to avoid recursion if PortalDestroy elog's */
 	VacuumRunning = false;
 
 	/*
 	 * Release our portal for cross-transaction memory.
 	 */
-	PortalDestroy(&vc_portal);
+	PortalDrop(&vc_portal);
 }
 
 /*
@@ -230,13 +230,13 @@ vc_shutdown()
 vc_abort()
 {
-	/* Clear flag first, to avoid recursion if PortalDestroy elog's */
+	/* Clear flag first, to avoid recursion if PortalDrop elog's */
 	VacuumRunning = false;
 
diff --git a/src/backend/executor/execTuples.c b/src/backend/executor/execTuples.c
index f1f6d15f1b00b5a5cf1b204818eae60bd5aedfa5..e31d7993a281b5d75bfd6520d211164d533cc43b 100644
--- a/src/backend/executor/execTuples.c
+++ b/src/backend/executor/execTuples.c
@@ -14,7 +14,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/executor/execTuples.c,v 1.32 1999/11/23 20:06:51 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/executor/execTuples.c,v 1.33 1999/12/10 03:55:51 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -23,7 +23,7 @@
  *
  *	 TABLE CREATE/DELETE
  *		ExecCreateTupleTable	- create a new tuple table
  *		ExecDestroyTupleTable	- destroy a table
  *
  *	 SLOT RESERVERATION
  *		ExecAllocTableSlot		- find an available slot in the table
@@ -84,7 +84,7 @@
  *
  *		At ExecEnd()
  *		----------------
  *		- EndPlan() calls ExecDestroyTupleTable() to clean up any remaining
  *		  tuples left over from executing the query.
  *
  *		The important thing to watch in the executor code is how pointers
@@ -178,7 +178,7 @@ ExecCreateTupleTable(int initialSize)	/* initial number of slots in
 }
 
 /* --------------------------------
- *		ExecDestroyTupleTable
+ *		ExecDropTupleTable
  *
  *		This pfrees the storage assigned to the tuple table and
  *		optionally pfrees the contents of the table also.
@@ -186,7 +186,7 @@ ExecCreateTupleTable(int initialSize)	/* initial number of slots in
  * --------------------------------
  */
 void
-ExecDestroyTupleTable(TupleTable table, /* tuple table */
+ExecDropTupleTable(TupleTable table, /* tuple table */
 					  bool shouldFree)	/* true if we should free slot
 										 * contents */
 {
@@ -23,7 +23,7 @@
  *	 TABLE CREATE/DELETE
  *		ExecCreateTupleTable	- create a new tuple table
- *		ExecDestroyTupleTable	- destroy a table
+ *		ExecDropTupleTable	- destroy a table
  *
  *	 SLOT RESERVERATION
@@ -84,7 +84,7 @@
  *		At ExecEnd()
  *		----------------
- *		- EndPlan() calls ExecDestroyTupleTable() to clean up any remaining
+ *		- EndPlan() calls ExecDropTupleTable() to clean up any remaining
  *		  tuples left over from executing the query.
  *
diff --git a/src/backend/libpq/be-fsstubs.c b/src/backend/libpq/be-fsstubs.c
index 280fdd9410d31bf70fb95a0eb4e4117d0bb558bb..b11392904872d1f2e79e9550a57f458d7b39f341 100644
--- a/src/backend/libpq/be-fsstubs.c
+++ b/src/backend/libpq/be-fsstubs.c
@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/libpq/be-fsstubs.c,v 1.41 1999/07/17 20:17:01 momjian Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/libpq/be-fsstubs.c,v 1.42 1999/12/10 03:55:53 momjian Exp $
  *
  * NOTES
  *	  This should be moved to a more appropriate place.  It is here
@@ -269,14 +269,14 @@ int
 lo_unlink(Oid lobjId)
 {
 	/*
 	 * inv_destroy does not need a context switch, indeed it doesn't
 	 * touch any LO-specific data structures at all.  (Again, that's
 	 * probably more than this module ought to be assuming.)
 	 *
 	 * XXX there ought to be some code to clean up any open LOs that
 	 * reference the specified relation... as is, they remain "open".
 	 */
-	return inv_destroy(lobjId);
+	return inv_drop(lobjId);
 }
 
 /*****************************************************************************
@@ -269,14 +269,14 @@ int
 {
 	/*
-	 * inv_destroy does not need a context switch, indeed it doesn't
+	 * inv_drop does not need a context switch, indeed it doesn't
 	 * touch any LO-specific data structures at all.  (Again, that's
 	 * probably more than this module ought to be assuming.)